@@ -119,6 +119,7 @@
 #define HAVE_STRUCT_STAT_ST_CTIM 1
 #define HAVE_STRUCT_STAT_ST_CTIMESPEC 1
 #define HAVE_STRUCT_STAT_ST_CTIMENSEC 1
+#define HAVE_STRUCT_TIMEVAL 1
 #define HAVE_STRUCT_TIMESPEC 1
 #define HAVE_STRUCT_TIMEZONE 1
 #define HAVE_CLOCKID_T 1
@@ -193,6 +194,7 @@
 #define HAVE_READLINK 1
 #define HAVE_READDIR_R 1
 #define HAVE_FSYNC 1
+#define HAVE_FDATASYNC 1
 #define HAVE_FCHOWN 1
 #define HAVE_SETITIMER 1
 #define HAVE_SETEUID 1
@@ -244,6 +246,7 @@
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_POLL 1
+#define HAVE_PPOLL 1
 #define HAVE_PREAD 1
 #define HAVE_SHUTDOWN 1
 #define HAVE_SIGALTSTACK 1
