@@ -13,7 +13,7 @@ module RbConfig
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "9"
   CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "392"
+  CONFIG["PATCHLEVEL"] = "448"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
@@ -58,13 +58,14 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.1"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared $(CCDLFLAGS)"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Werror=pointer-arith -Werror=write-strings -Werror=declaration-after-statement -Werror=implicit-function-declaration"
+  CONFIG["EXTDLDFLAGS"] = ""
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration"
   CONFIG["debugflags"] = "-ggdb"
   CONFIG["optflags"] = "-O3"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
@@ -98,6 +99,7 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ALLOCA"] = ""
+  CONFIG["POSTLINK"] = ":"
   CONFIG["WERRORFLAG"] = "-Werror"
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
@@ -140,21 +142,21 @@ module RbConfig
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.3"
+  CONFIG["target_os"] = "openbsd5.4"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "powerpc"
-  CONFIG["target"] = "powerpc-unknown-openbsd5.3"
-  CONFIG["host_os"] = "openbsd5.3"
+  CONFIG["target"] = "powerpc-unknown-openbsd5.4"
+  CONFIG["host_os"] = "openbsd5.4"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "powerpc"
-  CONFIG["host"] = "powerpc-unknown-openbsd5.3"
+  CONFIG["host"] = "powerpc-unknown-openbsd5.4"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.3"
+  CONFIG["build_os"] = "openbsd5.4"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "powerpc"
-  CONFIG["build"] = "powerpc-unknown-openbsd5.3"
-  CONFIG["RUBY_RELEASE_DATE"] = "2013-02-22"
+  CONFIG["build"] = "powerpc-unknown-openbsd5.4"
+  CONFIG["RUBY_RELEASE_DATE"] = "2013-06-27"
   CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.3"
   CONFIG["BASERUBY"] = "echo executable host ruby is required.  use --with-baseruby option.; false"
   CONFIG["target_alias"] = ""
